==> odoo_19.1a1.20251013.zip: odoo-19.1a1.post20251013/odoo/addons/pos_self_order/static/src/app/models/pos_order_line.js <==
import { PosOrderline } from "@point_of_sale/app/models/pos_order_line";
import { patch } from "@web/core/utils/patch";

patch(PosOrderline.prototype, {
    get changes() {
        const change = this.order_id.uiState.lineChanges[this.uuid];

        if (!change) {
            return {
                qty: this.qty,
                customer_note: this.customer_note,
                attribute_value_ids: JSON.stringify(
                    this.attribute_value_ids.map((a) => a.id).sort()
                ),
                custom_attribute_value_ids: JSON.stringify(
                    this.custom_attribute_value_ids.map((a) => a.id).sort()
                ),
            };
        }

        const diff = {
            qty: this.qty !== change.qty ? this.qty - change.qty : false,
            customer_note:
                this.customer_note !== change.customer_note ? change.customer_note : false,
            attribute_value_ids:
                JSON.stringify(this.attribute_value_ids.map((a) => a.id).sort()) !==
                change.attribute_value_ids
                    ? change.attribute_value_ids
                    : false,
            custom_attribute_value_ids:
                JSON.stringify(this.custom_attribute_value_ids.map((a) => a.id).sort()) !==
                change.custom_attribute_value_ids
                    ? change.custom_attribute_value_ids
                    : false,
        };
        return diff;
    },
    isLotTracked() {
        return false;
    },
    getDisplayPriceWithQty(qty) {
        const prices = this.getAllPrices(qty);

        if (this.config.iface_tax_included === "total") {
            return prices.priceWithTax;
        } else {
            return prices.priceWithoutTax;
        }
    },
});

==> odoo_19.2a1.20260207.zip: odoo-19.2a1.post20260207/odoo/addons/pos_self_order/static/src/app/models/pos_order_line.js <==
import { PosOrderline } from "@point_of_sale/app/models/pos_order_line";
import { patch } from "@web/core/utils/patch";

patch(PosOrderline.prototype, {
    get changes() {
        const change = this.order_id.uiState.lineChanges[this.uuid];

        if (!change) {
            return {
                qty: this.qty,
                customer_note: this.customer_note,
                attribute_value_ids: JSON.stringify(
                    this.attribute_value_ids.map((a) => a.id).sort()
                ),
                custom_attribute_value_ids: JSON.stringify(
                    this.custom_attribute_value_ids.map((a) => a.id).sort()
                ),
            };
        }

        const diff = {
            qty: this.qty !== change.qty ? this.qty - change.qty : false,
            customer_note:
                this.customer_note !== change.customer_note ? change.customer_note : false,
            attribute_value_ids:
                JSON.stringify(this.attribute_value_ids.map((a) => a.id).sort()) !==
                change.attribute_value_ids
                    ? change.attribute_value_ids
                    : false,
            custom_attribute_value_ids:
                JSON.stringify(this.custom_attribute_value_ids.map((a) => a.id).sort()) !==
                change.custom_attribute_value_ids
                    ? change.custom_attribute_value_ids
                    : false,
        };
        return diff;
    },
    isLotTracked() {
        return false;
    },
    getDisplayPriceWithQty(qty) {
        const prices = this.order_id._constructPriceData({ baseLineOpts: { quantity: qty } })
            .baseLineByLineUuids[this.uuid].tax_details;

        if (this.config.iface_tax_included === "total") {
            return prices.total_included;
        } else {
            return prices.total_excluded;
        }
    },
});
